<?php
/*Redirect to theme Welcome screen*/
global $pagenow;

if (is_admin() && 'themes.php' == $pagenow && isset($_GET['activated']) && !defined('ENVATO_HOSTED_SITE')) {
	pearl_update_custom_styles();
	wp_redirect(admin_url("admin.php?page=my-pearl"));
}

/*Theme info*/
function pearl_get_theme_info()
{
	$theme = wp_get_theme();
	$theme_name = $theme->get('Name');
	$theme_v = $theme->get('Version');

	$theme_info = array(
		'name' => $theme_name,
		'slug' => sanitize_file_name(strtolower($theme_name)),
		'v'    => $theme_v,
	);

	return $theme_info;
}

function pearl_organize_theme_response($theme)
{
	return array(
		'id'            => $theme['id'],
		'name'          => (!empty($theme['wordpress_theme_metadata']['theme_name']) ? $theme['wordpress_theme_metadata']['theme_name'] : ''),
		'author'        => (!empty($theme['wordpress_theme_metadata']['author_name']) ? $theme['wordpress_theme_metadata']['author_name'] : ''),
		'version'       => (!empty($theme['wordpress_theme_metadata']['version']) ? $theme['wordpress_theme_metadata']['version'] : ''),
		'url'           => (!empty($theme['url']) ? $theme['url'] : ''),
		'author_url'    => (!empty($theme['author_url']) ? $theme['author_url'] : ''),
		'thumbnail_url' => (!empty($theme['thumbnail_url']) ? $theme['thumbnail_url'] : ''),
		'rating'        => (!empty($theme['rating']) ? $theme['rating'] : ''),
	);
}

function pearl_get_token()
{
	$token = get_option('envato_market', array());
	$return_token = '';
	if (!empty($token['token'])) {
		$return_token = $token['token'];
	}

	return $return_token;
}

function pearl_check_token($args = array())
{

	/*If envato hosted*/
	if ( defined('ENVATO_HOSTED_SITE') ) return true;

	$has_token = get_site_transient('stm_theme_token_added');

	$purchased = false;

	if (false === $has_token) {
		$defaults = array(
			'headers'   => array(
				'Authorization' => 'Bearer ' . pearl_get_token(),
				'User-Agent'    => 'WordPress - Pearl',
			),
			'filter_by' => 'wordpress-themes',
			'timeout'   => 20,
		);
		$args = wp_parse_args($args, $defaults);

		$url = 'https://api.envato.com/v3/market/buyer/list-purchases?filter_by=wordpress-themes';

		$response = wp_remote_get(esc_url_raw($url), $args);

		// Check the response code.
		$response_code = wp_remote_retrieve_response_code($response);

		if ($response_code == '200') {
			$return = json_decode(wp_remote_retrieve_body($response), true);
			foreach ($return['results'] as $theme) {
				$theme_info = pearl_organize_theme_response($theme['item']);

				if ($theme_info['name'] == STM_ITEM_NAME) {
					$purchased = true;
					set_site_transient('stm_theme_token_added', 'token_set');
				}
			}

			if (!$purchased) {
				$purchased = false;
				delete_site_transient('stm_theme_token_added');
			}
		}
	} else {
		$purchased = true;
	}

	return $purchased;
}

function pearl_set_token()
{
	if (isset($_POST['stm_registration'])) {
		if (isset($_POST['stm_registration']['token'])) {
			delete_site_transient('stm_theme_token_added');

			$token = array();
			$token['token'] = sanitize_text_field($_POST['stm_registration']['token']);

			update_option('envato_market', $token);

			$envato_market = Envato_Market::instance();
			$envato_market->items()->set_themes(true);
		}
	}
}

add_action('init', 'pearl_set_token');

function pearl_convert_memory($size)
{
	$l = substr($size, -1);
	$ret = substr($size, 0, -1);
	switch (strtoupper($l)) {
		case 'P':
			$ret *= 1024;
		case 'T':
			$ret *= 1024;
		case 'G':
			$ret *= 1024;
		case 'M':
			$ret *= 1024;
		case 'K':
			$ret *= 1024;
	}
	return $ret;
}

function pearl_theme_support_url()
{
	return 'https://stylemixthemes.com/';
}

function pearl_get_plugin_tgm_link($plugin_path, $plugin_name)
{
	$installed_plugins = get_plugins();
	$plugins = TGM_Plugin_Activation::$instance->plugins;

	$plugin = array();
	if (!empty($plugins) and !empty($plugins[$plugin_name])) {
		$plugin = $plugins[$plugin_name];
	}


	$url = '';
	$install = false;

	if (empty($installed_plugins[$plugin_path])) {
		$url = esc_url(wp_nonce_url(
			add_query_arg(
				array(
					'page'          => urlencode(TGM_Plugin_Activation::$instance->menu),
					'plugin'        => urlencode($plugin['slug']),
					'plugin_name'   => urlencode($plugin['name']),
					'tgmpa-install' => 'install-plugin',
					'return_url'    => 'stm-admin-demos',
				),
				TGM_Plugin_Activation::$instance->get_tgmpa_url()
			),
			'tgmpa-install',
			'tgmpa-nonce'
		));
		$install = true;
	} else {
		$url = esc_url(wp_nonce_url(
			add_query_arg(
				array(
					'page'          => urlencode(TGM_Plugin_Activation::$instance->menu),
					'plugin'        => urlencode($plugin['slug']),
					'plugin_name'   => urlencode($plugin['name']),
					'tgmpa-install' => 'activate-plugin',
					'return_url'    => 'stm-admin-demos',
				),
				TGM_Plugin_Activation::$instance->get_tgmpa_url()
			),
			'tgmpa-install',
			'tgmpa-nonce'
		));
	}

	if ($install) {
		$plugin['plugin_url_activate'] = '<a class="button button-primary" href="' . esc_url($url) . '">' . esc_html__('Install', 'pearl' ) . '</a>';
	} else {
		$plugin['plugin_url_activate'] = '<a class="button button-primary" href="' . esc_url($url) . '">' . esc_html__('Activate', 'pearl' ) . '</a>';
	}

	return $plugin;
}

function pearl_get_admin_images_url($image)
{
	return esc_url(get_template_directory_uri() . '/includes/admin/product_registration/assets/img/' . $image);
}

/*Plugin installer via tgmpa*/
add_action('wp_ajax_pearl_install_plugin', 'pearl_install_plugin');
function pearl_install_plugin()
{
	$r = array();
	$plugins = pearl_require_plugins(true);
	$layout = sanitize_text_field($_GET['layout']);
	$layout_plugins_config = pearl_layout_plugins($layout);
	$layout_plugins = array();

	foreach($plugins as $plugin_name => $plugin_info) {
		if(in_array($plugin_name, $layout_plugins_config)) {
			$layout_plugins[$plugin_name] = $plugin_info;
		}
	}

	$plugins = $layout_plugins;

	$plugin_slug = sanitize_text_field($_GET['plugin']);

	if (!current_user_can('install_plugins')) {
		return;
	}

	/*if install demo*/
	if($plugin_slug === 'import_demo') {
		$r['import_demo'] = true;
		wp_send_json($r);
	}

	/*No plugin*/
	if (empty($plugin_slug) and !empty($plugins[$plugin_slug])) {
		wp_send_json(array('error' => esc_html__('Error occured', 'pearl')));
		exit;
	}

	require_once ABSPATH . 'wp-load.php';
	require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
	require_once ABSPATH . 'wp-admin/includes/class-plugin-upgrader.php';
	require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
	require_once ABSPATH . 'wp-admin/includes/plugin.php';
	require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader-skin.php';
	require_once get_template_directory() . '/includes/admin/product_registration/includes/stm_upgrader_skin.php';


	$plugin_upgrader = new Plugin_Upgrader(new STM_Plugin_Upgrader_Skin(array('plugin' => $plugin_slug)));
	$plugin_info = $plugins[$plugin_slug];
	$next = pearl_get_next($plugins, $plugin_slug);


	if (!empty($plugin_info['source'])) {
		$source = $plugin_info['source'];
	} else {
		$response = plugins_api('plugin_information', array('slug' => $plugin_slug));
		if(!is_wp_error($response) and !empty($response->download_link)) {
			$source = $response->download_link;
		}
	};

	$r['source'] = $source;

	if(!empty($source)) {
		$installed = (pearl_check_plugin_active($plugin_slug)) ? true : $plugin_upgrader->install($source);
		if(is_wp_error($installed)) {
			$r['error'] = $installed->get_error_message();
		} else {
			if(!empty($next)) {
				$r['next'] = $next['slug'];
			}
			pearl_activate_plugin($plugin_slug);
			$r['installed'] = true;
			$r['activated'] = true;
			$r['plugin_slug'] = $plugin_slug;
		}
	}

	/*Check if last*/
	if(end($plugins) === $plugin_info) $r['import_demo'] = true;

	wp_send_json($r);
	exit;
}

function pearl_check_plugin_active($slug) {
	return is_plugin_active(pearl_get_plugin_main_path($slug));
}

function pearl_activate_plugin($slug) {
	activate_plugin(pearl_get_plugin_main_path($slug));
}

function pearl_get_plugin_main_path($slug) {
	$plugin_data = get_plugins('/' . $slug);
	if(!empty($plugin_data)) {
		$plugin_file = array_keys($plugin_data);
		$plugin_path = $slug . '/' . $plugin_file[0];
	} else {
		$plugin_path = false;
	}
	return $plugin_path;
}

function pearl_get_next($array, $key)
{
	$currentKey = key($array);
	while ($currentKey !== null && $currentKey != $key) {
		next($array);
		$currentKey = key($array);
	}
	return next($array);
}