<?php

/**
 * Get theme current layout
 *
 * @return mixed|void
 */
function pearl_get_layout()
{
	return (apply_filters('stm_layout', get_option('stm_layout', 'business')));
}

/**
 * Get layout configs
 *
 * @param string $layout
 * @return mixed
 */
function pearl_get_layout_config($layout = 'business')
{
	$layout = pearl_get_layout();
	$layouts = pearl_layout_configs();

	return $layouts[$layout];
}

/**
 * Default layouts configs
 *
 * @return array
 */
function pearl_layout_configs()
{
	$layouts = array(
		'business' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'subsets' => 'latin,latin-ext',
				'color' => '#222',
				'size' => '14',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Exo',
				'subsets' => 'latin,latin-ext',
				'color' => '#3c98ff',
				'fw' => '800',
			),
			'main_color' => '#3c98ff',
			'secondary_color' => '#3c98ff',
			'third_color' => '#293742',
			'logo' => 'light'
		),
		'construction' => array(
			'main_font' => array(
				'name' => 'Roboto',
				'color' => '#333333',
				'size' => '14',
				'fw' => '400',
				'ln' => '16'
			),
			'secondary_font' => array(
				'name' => 'Roboto',
				'subsets' => 'latin,latin-ext',
				'color' => '#333',
				'fw' => '900'
			),
			'main_color' => '#dac725',
			'secondary_color' => '#dac725',
			'third_color' => '#333333',
			'logo' => 'dark'
		),
		'logistics' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'color' => '#333333',
				'size' => '14',
				'fw' => '400',
				'ln' => '16'
			),
			'secondary_font' => array(
				'name' => 'Poppins',
				'subsets' => 'latin,latin-ext',
				'color' => '#002040',
				'fw' => '900'
			),
			'main_color' => '#002040',
			'secondary_color' => '#58c747',
			'third_color' => '#122a4c',
			'logo' => 'light'
		),
		'beauty' => array(
			'main_font' => array(
				'name' => 'Montserrat',
				'color' => '#808080',
				'size' => '14',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Playfair Display',
				'subsets' => 'latin,latin-ext',
				'color' => '#5c373e',
				'fw' => '700'
			),
			'main_color' => '#c54045',
			'secondary_color' => '#63bac1',
			'third_color' => '#5c373e',
			'logo' => 'dark'
		),
		'healthcoach' => array(
			'main_font' => array(
				'name' => 'Source+Sans+Pro',
				'color' => '#888888',
				'size' => '16',
				'fw' => '400',
				'ln' => '30'
			),
			'secondary_font' => array(
				'name' => 'Lobster+Two',
				'subsets' => 'latin,latin-ext',
				'color' => '#192227',
				'fw' => '700'
			),
			'main_color' => '#74c000',
			'secondary_color' => '#ff6445',
			'third_color' => '#192227',
			'logo' => 'dark'
		),
		'medicall' => array(
			'main_font' => array(
				'name' => 'Montserrat',
				'color' => '#595959',
				'size' => '15',
				'fw' => '300',
				'ln' => '30'
			),
			'secondary_font' => array(
				'name' => 'Rubik',
				'subsets' => 'latin,latin-ext',
				'color' => '#333333',
				'fw' => '400'
			),
			'main_color' => '#74c000',
			'secondary_color' => '#ff6445',
			'third_color' => '#192227',
			'logo' => 'dark'
		),
		'charity' => array(
			'main_font' => array(
				'name' => 'Fira Sans',
				'color' => '#808080',
				'size' => '16',
				'fw' => '400',
				'ln' => '28'
			),
			'secondary_font' => array(
				'name' => 'PT Serif',
				'subsets' => 'latin,latin-ext',
				'color' => '#591e00',
				'fw' => '600'
			),
			'main_color' => '#fdb714',
			'secondary_color' => '#00749c',
			'third_color' => '#591e00',
			'logo' => 'dark'
		),
		'artist' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'color' => '#0c0c0d',
				'size' => '15',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Montserrat',
				'subsets' => 'latin,latin-ext',
				'color' => '#0c0c0d',
				'fw' => '700'
			),
			'main_color' => '#d61515',
			'secondary_color' => '#d61515',
			'third_color' => '#0c0c0d',
			'logo' => 'dark'
		),
		'restaurant' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'subsets' => 'latin,latin-ext',
				'color' => '#222',
				'size' => '14',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Exo',
				'subsets' => 'latin,latin-ext',
				'color' => '#3c98ff',
				'fw' => '800',
			),
			'main_color' => '#3c98ff',
			'secondary_color' => '#3c98ff',
			'third_color' => '#293742',
			'logo' => 'light'
		),
		'rental' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'subsets' => 'latin,latin-ext',
				'color' => '#222',
				'size' => '14',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Exo',
				'subsets' => 'latin,latin-ext',
				'color' => '#3c98ff',
				'fw' => '800',
			),
			'main_color' => '#3c98ff',
			'secondary_color' => '#3c98ff',
			'third_color' => '#293742',
			'logo' => 'light'
		),
		'portfolio' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'subsets' => 'latin,latin-ext',
				'color' => '#222',
				'size' => '14',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Exo',
				'subsets' => 'latin,latin-ext',
				'color' => '#3c98ff',
				'fw' => '800',
			),
			'main_color' => '#3c98ff',
			'secondary_color' => '#3c98ff',
			'third_color' => '#293742',
			'logo' => 'dark'
		),
        'store' => array(
            'main_font' => array(
                'name' => 'Encode Sans Expanded',
                'subsets' => 'latin,latin-ext',
                'color' => '#000',
                'size' => '14',
                'fw' => '400',
                'ln' => '30'
            ),
            'secondary_font' => array(
                'name' => 'Raleway',
                'subsets' => 'latin,latin-ext',
                'color' => '#000',
                'fw' => '400',
            ),
            'main_color' => '#000000',
            'secondary_color' => '#c64047',
            'third_color' => '#f47969',
            'logo' => 'dark'
        ),
		'personal_blog' => array(
			'main_font' => array(
				'name' => 'Open Sans',
				'subsets' => 'latin,latin-ext',
				'color' => '#222',
				'size' => '14',
				'fw' => '400',
				'ln' => '24'
			),
			'secondary_font' => array(
				'name' => 'Exo',
				'subsets' => 'latin,latin-ext',
				'color' => '#3c98ff',
				'fw' => '400',
			),
			'main_color' => '#3c98ff',
			'secondary_color' => '#3c98ff',
			'third_color' => '#293742',
			'logo' => 'dark'
		),
		'church' => array(
			'main_font' => array(
				'name' => 'Quattrocento Sans',
				'subsets' => 'latin,latin-ext',
				'color' => '#808080',
				'size' => '16',
				'fw' => '400',
				'ln' => '26'
			),
			'secondary_font' => array(
				'name' => 'Libre Baskerville',
				'subsets' => 'latin,latin-ext',
				'color' => '#1a1a1a',
				'fw' => '6]700',
			),
			'menu' => array(
				'Main menu' => array(
					'row' => 'center',
					'col' => 'right'
				),
				'Top menu' => array(
					'row' => 'top',
					'col' => 'center'
				)
			),
			'main_color' => '#d9b684',
			'secondary_color' => '#789cb6',
			'third_color' => '#1a1a1a',
			'logo' => 'light'
		),
		'startup' => array(
			'main_font' => array(
				'name' => 'Muli',
				'subsets' => 'latin,latin-ext',
				'color' => '#222527',
				'size' => '28',
				'fw' => '700',
				'ln' => '40'
			),
			'secondary_font' => array(
				'name' => 'Poppins',
				'subsets' => 'latin,latin-ext',
				'color' => '#222527',
				'fw' => '600',
			),
			'main_color' => '#0037c2',
			'secondary_color' => '#0037c2',
			'third_color' => '#222527',
			'logo' => 'light'
		),
        'viral' => array(
            'main_font' => array(
                'name' => 'Roboto',
                'subsets' => 'latin,latin-ext',
                'color' => '#404040',
                'size' => '16',
                'fw' => '400',
                'ln' => '30'
            ),
            'secondary_font' => array(
                'name' => 'Poppins',
                'subsets' => 'latin,latin-ext',
                'color' => '#000000',
                'fw' => '700',
            ),
            'main_color' => '#000000',
            'secondary_color' => '#289dfd',
            'third_color' => '#ffffff',
            'logo' => 'dark'
        ),
	);

	return $layouts;
}


function pearl_layout_plugins($layout = 'business') {
	$required = array(
		'stm-configurations',
		'js_composer',
		'contact-form-7',
	);
	$plugins = array(
		'business' => array(
			'revslider',
			'breadcrumb-navxt',
			'mailchimp-for-wp',
			'booked',
		),
		'construction' => array(
			'revslider',
			'breadcrumb-navxt',
		),
		'logistics' => array(
			'breadcrumb-navxt',
			'recent-tweets-widget',
			'revslider',
		),
		'beauty' => array(
			'breadcrumb-navxt',
			'booked',
			'revslider',
			'recent-tweets-widget',
		),
		'healthcoach' => array(
			'breadcrumb-navxt',
			'mailchimp-for-wp',
		),
		'medicall' => array(
			'breadcrumb-navxt',
			'booked',
		),
		'charity' => array(
			'breadcrumb-navxt',
			'mailchimp-for-wp',
		),
		'artist' => array(
			'breadcrumb-navxt',
			'recent-tweets-widget',
			'revslider',
			'booked',
			'mailchimp-for-wp',
		),
		'restaurant' => array(
			'breadcrumb-navxt',
			'open-table-widget',
			'revslider',
		),
        'rental' => array(
			'breadcrumb-navxt',
            'revslider',
            'recent-tweets-widget',
            'mailchimp-for-wp',
        ),
		'portfolio' => array(

		),
        'store' => array(
            'yith-woocommerce-wishlist',
            'woocommerce',
            'revslider',
            'breadcrumb-navxt',
            'mailchimp-for-wp',
            'instagram-feed'
        ),
		'personal_blog' => array(
			'amp',
			'mailchimp-for-wp',
			'instagram-feed'
		),
		'church' => array(
			'breadcrumb-navxt',
			'revslider'
		),
		'startup' => array(
			'mailchimp-for-wp',
		),
        'viral' => array(
            'mailchimp-for-wp',
        ),
	);

	return array_merge($required, $plugins[$layout]);
}